#
# Conditional build:
%bcond_without	tests	# don't perform make check
%bcond_without	asm	# ix86 asm optimizations

%ifnarch %{ix86}
# Speed-optimized CRC64 using slicing-by-four algorithm. This uses only i386
# instructions, but it is optimized for i686 and later (including e.g. Pentium
# II/III/IV, Athlon XP, and Core 2).
%undefine	with_asm
%endif

%if "%{pld_release}" == "ac"
%undefine	with_asm
%endif

Summary:	LZMA Encoder/Decoder
Summary(pl.UTF-8):	Koder/Dekoder LZMA
Name:		xz
Version:	5.2.5
Release:	1
Epoch:		1
License:	LGPL v2.1+, helper scripts on GPL v2+
Group:		Applications/Archiving
Source0:	https://tukaani.org/xz/%{name}-%{version}.tar.bz2
# Source0-md5:	33ab3ef79aa1146b83b778210e7b0a54
Patch0:		%{name}-parallel.patch
Patch1:		%{name}-memlimit.patch
URL:		https://tukaani.org/xz/
%{?with_asm:BuildRequires:	gcc >= 5:3.4}
BuildRequires:	rpm >= 4.4.9-56
BuildRequires:	rpmbuild(macros) >= 1.402
Requires:	%{name}-libs = %{epoch}:%{version}-%{release}
Suggests:	mktemp
Provides:	lzma = %{epoch}:%{version}-%{release}
Obsoletes:	lzma < 1:4.999.6
Conflicts:	rpm < 4.4.9
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
LZMA is default and general compression method of 7z format in 7-Zip
program. LZMA provides high compression ratio and very fast
decompression, so it is very suitable for embedded applications. For
example, it can be used for ROM (firmware) compressing.

LZMA features:

- Compressing speed: 500 KB/s on 1 GHz CPU
- Decompressing speed:
  - 8-12 MB/s on 1 GHz Intel Pentium 3 or AMD Athlon.
  - 500-1000 KB/s on 100 MHz ARM, MIPS, PowerPC or other simple RISC
    CPU.
- Small memory requirements for decompressing: 8-32 KB + dictionary
  size
- Small code size for decompressing: 2-8 KB (depending from speed
  optimizations)

%description -l pl.UTF-8
LZMA jest domyślnym i ogólnym algorytmem kompresji formatu 7z
stosowanego przez 7-Zip. LZMA zapewnia wysoki stopień kompresji i
bardzo szybką dekompresję, więc nadaje się do zastosowań osadzonych.
Przykładowo, może być użyty do kompresji ROM-u (firmware'u).

Cechy LZMA:

- Szybkość kompresowania: 500 KB/s na 1 GHz procesorze,
- Szybkość dekompresowania:
  - 8-12 MB/s na 1 GHz Pentium 3 lub Athlonie,
  - 500-1000 KB/s na 100 MHz procesorach ARM, MIPS, PowerPC lub innych
    prostych RISC-ach,
- Mała ilość pamięci potrzebna do dekompresowania: 8-32 KB + rozmiar
  słownika,
- Mały rozmiar kodu dekompresującego: 2-8 KB (w zależności od opcji
  optymalizacji).

%package libs
Summary:	LZMA shared library
Summary(pl.UTF-8):	Biblioteka współdzielona LZMA
Group:		Libraries
Provides:	lzma-libs = %{epoch}:%{version}-%{release}
Obsoletes:	lzma-libs < 1:4.999.6

%description libs
LZMA shared library.

%description libs -l pl.UTF-8
Biblioteka współdzielona LZMA.

%package devel
Summary:	Header file for LZMA library
Summary(pl.UTF-8):	Plik nagłówkowy biblioteki LZMA
Group:		Development/Libraries
Requires:	%{name}-libs = %{epoch}:%{version}-%{release}
Provides:	lzma-devel = %{epoch}:%{version}-%{release}
Obsoletes:	lzma-devel < 1:4.999.6

%description devel
Header file for LZMA library.

%description devel -l pl.UTF-8
Plik nagłówkowy biblioteki LZMA.

%package static
Summary:	LZMA static library
Summary(pl.UTF-8):	Biblioteka statyczna LZMA
Group:		Development/Libraries
Requires:	%{name}-devel = %{epoch}:%{version}-%{release}
Provides:	lzma-static = %{epoch}:%{version}-%{release}
Obsoletes:	lzma-static < 1:4.999.6

%description static
LZMA static library.

%description static -l pl.UTF-8
Biblioteka statyczna LZMA.

%prep
%setup -q
%patch0 -p1
%patch1 -p1

%build
%configure \
	%{!?with_asm:--disable-assembler}
%{__make}

%{?with_tests:%{__make} check}

%install
rm -rf $RPM_BUILD_ROOT
install -d $RPM_BUILD_ROOT{/etc/env.d,/%{_lib}}
%{__make} install \
	DESTDIR=$RPM_BUILD_ROOT

%{__rm} -r $RPM_BUILD_ROOT%{_docdir}/%{name}

install -d $RPM_BUILD_ROOT%{_examplesdir}/%{name}-%{version}
cp -a doc/examples*  $RPM_BUILD_ROOT%{_examplesdir}/%{name}-%{version}

mv -f $RPM_BUILD_ROOT%{_libdir}/liblzma.so.* $RPM_BUILD_ROOT/%{_lib}
ln -sf /%{_lib}/$(basename $RPM_BUILD_ROOT/%{_lib}/liblzma.so.*.*.*) $RPM_BUILD_ROOT%{_libdir}/liblzma.so

echo '#XZ_OPT="--threads=2"' > $RPM_BUILD_ROOT/etc/env.d/XZ_OPT

%find_lang %{name}

%clean
rm -rf $RPM_BUILD_ROOT

%post	libs -p /sbin/ldconfig
%postun	libs -p /sbin/ldconfig

%files -f %{name}.lang
%defattr(644,root,root,755)
%config(noreplace,missingok) %verify(not md5 mtime size) /etc/env.d/XZ_OPT
%attr(755,root,root) %{_bindir}/lz*
%attr(755,root,root) %{_bindir}/unlzma
%attr(755,root,root) %{_bindir}/unxz
%attr(755,root,root) %{_bindir}/xz*
%{_mandir}/man1/lz*.1*
%{_mandir}/man1/unlzma.1*
%{_mandir}/man1/unxz.1*
%{_mandir}/man1/xz*.1*

%files libs
%defattr(644,root,root,755)
%doc AUTHORS COPYING README THANKS
%doc doc/*.txt
%attr(755,root,root) /%{_lib}/liblzma.so.*.*.*
%attr(755,root,root) %ghost /%{_lib}/liblzma.so.5

%files devel
%defattr(644,root,root,755)
%attr(755,root,root) %{_libdir}/liblzma.so
%{_libdir}/liblzma.la
%{_includedir}/lzma.h
%{_includedir}/lzma
%{_pkgconfigdir}/liblzma.pc
%{_examplesdir}/%{name}-%{version}

%files static
%defattr(644,root,root,755)
%{_libdir}/liblzma.a
%changelog
* Fri Mar 20 2020 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/xz.git;a=log;h=master

* Fri Mar 20 2020 Arkadiusz Miśkiewicz <arekm@maven.pl> f5e3ff8
- up to 5.2.5

* Thu May 10 2018 Jakub Bogusz <qboosh@pld-linux.org> 3622859
- updated to 5.2.4

* Fri Mar 03 2017 Marcin Banasiak <marcin.banasiak@gmail.com> 8cf85c4
- Update to 5.2.3

* Tue Oct 13 2015 Jakub Bogusz <qboosh@pld-linux.org> 7f0bc7f
- updated to 5.2.2

* Sun Mar 01 2015 Jakub Bogusz <qboosh@pld-linux.org> 1b0620b
- updated to 5.2.1

* Tue Feb 24 2015 Jan Rękorajski <baggins@pld-linux.org> e8b45f5
- x32 rebuild
- release 2 (by relup.sh)

* Wed Dec 24 2014 Jakub Bogusz <qboosh@pld-linux.org> 2b3d069
- removed obsolete pl.po-update patch

* Sun Dec 21 2014 Arkadiusz Miśkiewicz <arekm@maven.pl> f480a40
- up to 5.2.0

* Wed Oct 15 2014 Jakub Bogusz <qboosh@pld-linux.org> 197d662
- updated to 5.1.4beta (include full version information; the next release will be 5.2.0)
- added xz-pl.po-update patch (will be sent upstream)

* Sun Nov 10 2013 Elan Ruusamäe <glen@delfi.ee> e2c9b1f
- check-files cleanup, package examples to -devel

* Sat Oct 26 2013 Arkadiusz Miśkiewicz <arekm@maven.pl> a17a78a
- up to 5.1.3

* Mon Mar 04 2013 Arkadiusz Miśkiewicz <arekm@maven.pl> 6685de1
- rel 3; avoid trying to use more memory than 32bit process can handle

* Mon Mar 04 2013 Arkadiusz Miśkiewicz <arekm@maven.pl> 4e36462
- rel 3; avoid trying to use more memory than 32bit process can handle

* Thu Nov 15 2012 Arkadiusz Miśkiewicz <arekm@maven.pl> 75b7e3b
- rel 2; realloc patch from git

* Sun Jul 08 2012 Jakub Bogusz <qboosh@pld-linux.org> 092d9d2
- updated to 5.1.2alpha
- removed obsolete git patch

* Sun Oct 23 2011 Arkadiusz Miśkiewicz <arekm@maven.pl> 6d34216
- rel 6; fix segfault and deadlock (from upstream)

* Sun Oct 23 2011 Arkadiusz Miśkiewicz <arekm@maven.pl> 301f6f2
- release 5

* Sun Oct 23 2011 Arkadiusz Miśkiewicz <arekm@maven.pl> ca75bcd
- use 80% of memory max (90 looks too much)

* Sat Oct 22 2011 Arkadiusz Miśkiewicz <arekm@maven.pl> 13953fd
- default in pld

* Sat Oct 22 2011 Arkadiusz Miśkiewicz <arekm@maven.pl> dbbc267
- initialize everything in hardware_init (hint from upstream author)

